@@ -1,28 +1,13 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "logModeConfiguration.h"
 
 #include "defaults.h"
-#include "logging.h"
+#include "ksystemlog_debug.h"
 
 #include <KLocalizedString>
 
@@ -101,7 +86,7 @@ Reader* ReaderFactory::createReader(LogMode* logMode) {
         return reader;
     }
 
-  logCritical() << "LogMode not found : returns NULL Reader";
+  qCCritical(KSYSTEMLOG) << "LogMode not found : returns NULL Reader";
     return NULL;
 }
 */
@@ -214,7 +199,7 @@ LogFile LogModeConfiguration::findGenericLogFile(const QString &file)
 
     const QUrl url = QUrl::fromLocalFile(file);
     if (!url.isValid()) {
-        logWarning() << i18n("URL '%1' is not valid, skipping this URL.", url.path());
+        qCWarning(KSYSTEMLOG) << i18n("URL '%1' is not valid, skipping this URL.", url.path());
         return LogFile(QUrl(), Globals::instance().noLogLevel());
     }
     return LogFile(url, level);
@@ -242,7 +227,7 @@ QVector<LogFile> LogModeConfiguration::findNoModeLogFiles(const QStringList &str
     for (const QString &string : stringList) {
         const QUrl url = QUrl::fromLocalFile(string);
         if (!url.isValid()) {
-            logWarning() << i18n("URL '%1' is not valid, skipping this URL.", url.path());
+            qCWarning(KSYSTEMLOG) << i18n("URL '%1' is not valid, skipping this URL.", url.path());
             continue;
         }
 
